/*
 * openwms.org, the Open Warehouse Management System.
 *
 * This file is part of openwms.org.
 *
 * openwms.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * openwms.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software. If not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.openwms.core.domain {

    import flash.utils.IDataInput;
    import flash.utils.IDataOutput;
    import org.granite.collections.IPersistentCollection;
    import org.granite.meta;

    use namespace meta;

    [Bindable]
    public class ModuleBase extends AbstractEntity implements DomainObject {

        private var __initialized:Boolean = true;
        private var __detachedState:String = null;

        protected var _description:String;
        protected var _id:Number;
        protected var _loadOnStartup:Boolean;
        protected var _loaded:Boolean;
        protected var _moduleName:String;
        protected var _startupOrder:int;
        protected var _url:String;
        protected var _version:Number;

        override meta function isInitialized(name:String = null):Boolean {
            if (!name)
                return __initialized;

            var property:* = this[name];
            return (
                (!(property is Module) || (property as Module).meta::isInitialized()) &&
                (!(property is IPersistentCollection) || (property as IPersistentCollection).isInitialized())
            );
        }

        public function set description(value:String):void {
            _description = value;
        }
        public function get description():String {
            return _description;
        }

        public function get id():Number {
            return _id;
        }

        public function set loadOnStartup(value:Boolean):void {
            _loadOnStartup = value;
        }
        public function get loadOnStartup():Boolean {
            return _loadOnStartup;
        }

        public function set loaded(value:Boolean):void {
            _loaded = value;
        }
        public function get loaded():Boolean {
            return _loaded;
        }

        public function set moduleName(value:String):void {
            _moduleName = value;
        }
        public function get moduleName():String {
            return _moduleName;
        }

        public function set startupOrder(value:int):void {
            _startupOrder = value;
        }
        public function get startupOrder():int {
            return _startupOrder;
        }

        public function set url(value:String):void {
            _url = value;
        }
        public function get url():String {
            return _url;
        }

        public function set version(value:Number):void {
            _version = value;
        }
        public function get version():Number {
            return _version;
        }

        public function isNew():Boolean {
            return true;
        }

        override public function readExternal(input:IDataInput):void {
            __initialized = input.readObject() as Boolean;
            __detachedState = input.readObject() as String;
            if (meta::isInitialized()) {
                super.readExternal(input);
                _description = input.readObject() as String;
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
                _loadOnStartup = input.readObject() as Boolean;
                _loaded = input.readObject() as Boolean;
                _moduleName = input.readObject() as String;
                _startupOrder = input.readObject() as int;
                _url = input.readObject() as String;
                _version = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
            else {
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
        }

        override public function writeExternal(output:IDataOutput):void {
            output.writeObject(__initialized);
            output.writeObject(__detachedState);
            if (meta::isInitialized()) {
                super.writeExternal(output);
                output.writeObject(_description);
                output.writeObject(_id);
                output.writeObject(_loadOnStartup);
                output.writeObject(_loaded);
                output.writeObject(_moduleName);
                output.writeObject(_startupOrder);
                output.writeObject(_url);
                output.writeObject(_version);
            }
            else {
                output.writeObject(_id);
            }
        }
    }
}