/*
 * openwms.org, the Open Warehouse Management System.
 *
 * This file is part of openwms.org.
 *
 * openwms.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * openwms.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software. If not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.openwms.core.domain.system {

    import flash.utils.IDataInput;
    import flash.utils.IDataOutput;
    import org.granite.collections.IPersistentCollection;
    import org.granite.meta;
    import org.openwms.core.domain.AbstractEntity;
    import org.openwms.core.domain.DomainObject;

    use namespace meta;

    [Bindable]
    public class AbstractPreferenceBase extends AbstractEntity implements DomainObject {

        private var __initialized:Boolean = true;
        private var __detachedState:String = null;

        protected var _description:String;
        protected var _floatValue:Number;
        protected var _fromFile:Boolean;
        protected var _id:Number;
        protected var _maximum:int;
        protected var _minimum:int;
        protected var _value:String;
        protected var _version:Number;

        override meta function isInitialized(name:String = null):Boolean {
            if (!name)
                return __initialized;

            var property:* = this[name];
            return (
                (!(property is AbstractPreference) || (property as AbstractPreference).meta::isInitialized()) &&
                (!(property is IPersistentCollection) || (property as IPersistentCollection).isInitialized())
            );
        }

        public function set description(value:String):void {
            _description = value;
        }
        public function get description():String {
            return _description;
        }

        public function set floatValue(value:Number):void {
            _floatValue = value;
        }
        public function get floatValue():Number {
            return _floatValue;
        }

        public function set fromFile(value:Boolean):void {
            _fromFile = value;
        }
        public function get fromFile():Boolean {
            return _fromFile;
        }

        public function get id():Number {
            return _id;
        }

        public function set maximum(value:int):void {
            _maximum = value;
        }
        public function get maximum():int {
            return _maximum;
        }

        public function set minimum(value:int):void {
            _minimum = value;
        }
        public function get minimum():int {
            return _minimum;
        }

        public function set value(value:String):void {
            _value = value;
        }
        public function get value():String {
            return _value;
        }

        public function set version(value:Number):void {
            _version = value;
        }
        public function get version():Number {
            return _version;
        }

        public function isNew():Boolean {
            return true;
        }

        override public function readExternal(input:IDataInput):void {
            __initialized = input.readObject() as Boolean;
            __detachedState = input.readObject() as String;
            if (meta::isInitialized()) {
                super.readExternal(input);
                _description = input.readObject() as String;
                _floatValue = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
                _fromFile = input.readObject() as Boolean;
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
                _maximum = input.readObject() as int;
                _minimum = input.readObject() as int;
                _value = input.readObject() as String;
                _version = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
            else {
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
        }

        override public function writeExternal(output:IDataOutput):void {
            output.writeObject(__initialized);
            output.writeObject(__detachedState);
            if (meta::isInitialized()) {
                super.writeExternal(output);
                output.writeObject(_description);
                output.writeObject(_floatValue);
                output.writeObject(_fromFile);
                output.writeObject(_id);
                output.writeObject(_maximum);
                output.writeObject(_minimum);
                output.writeObject(_value);
                output.writeObject(_version);
            }
            else {
                output.writeObject(_id);
            }
        }
    }
}