/*
 * openwms.org, the Open Warehouse Management System.
 *
 * This file is part of openwms.org.
 *
 * openwms.org is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * openwms.org is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software. If not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.openwms.core.domain.system.usermanagement {

    import flash.utils.IDataInput;
    import flash.utils.IDataOutput;
    import mx.collections.ListCollectionView;
    import org.granite.collections.IPersistentCollection;
    import org.granite.meta;
    import org.openwms.core.domain.AbstractEntity;
    import org.openwms.core.domain.DomainObject;

    use namespace meta;

    [Bindable]
    public class UserBase extends AbstractEntity implements DomainObject {

        private var __initialized:Boolean = true;
        private var __detachedState:String = null;

        protected var _enabled:Boolean;
        protected var _expirationDate:Date;
        protected var _extern:Boolean;
        protected var _fullname:String;
        protected var _id:Number;
        protected var _lastPasswordChange:Date;
        protected var _locked:Boolean;
        protected var _password:String;
        protected var _passwords:ListCollectionView;
        protected var _preferences:ListCollectionView;
        protected var _roles:ListCollectionView;
        protected var _savedPassword:String;
        protected var _userDetails:UserDetails;
        protected var _username:String;
        protected var _version:Number;

        override meta function isInitialized(name:String = null):Boolean {
            if (!name)
                return __initialized;

            var property:* = this[name];
            return (
                (!(property is User) || (property as User).meta::isInitialized()) &&
                (!(property is IPersistentCollection) || (property as IPersistentCollection).isInitialized())
            );
        }

        public function set enabled(value:Boolean):void {
            _enabled = value;
        }
        public function get enabled():Boolean {
            return _enabled;
        }

        public function set expirationDate(value:Date):void {
            _expirationDate = value;
        }
        public function get expirationDate():Date {
            return _expirationDate;
        }

        public function set fullname(value:String):void {
            _fullname = value;
        }
        public function get fullname():String {
            return _fullname;
        }

        public function get id():Number {
            return _id;
        }

        public function get lastPasswordChange():Date {
            return _lastPasswordChange;
        }

        public function set locked(value:Boolean):void {
            _locked = value;
        }
        public function get locked():Boolean {
            return _locked;
        }

        public function set password(value:String):void {
            _password = value;
        }
        public function get password():String {
            return _password;
        }

        public function get passwords():ListCollectionView {
            return _passwords;
        }

        public function set preferences(value:ListCollectionView):void {
            _preferences = value;
        }
        public function get preferences():ListCollectionView {
            return _preferences;
        }

        public function set roles(value:ListCollectionView):void {
            _roles = value;
        }
        public function get roles():ListCollectionView {
            return _roles;
        }

        public function set userDetails(value:UserDetails):void {
            _userDetails = value;
        }
        public function get userDetails():UserDetails {
            return _userDetails;
        }

        public function get username():String {
            return _username;
        }

        public function set version(value:Number):void {
            _version = value;
        }
        public function get version():Number {
            return _version;
        }

        public function isNew():Boolean {
            return true;
        }

        override public function readExternal(input:IDataInput):void {
            __initialized = input.readObject() as Boolean;
            __detachedState = input.readObject() as String;
            if (meta::isInitialized()) {
                super.readExternal(input);
                _enabled = input.readObject() as Boolean;
                _expirationDate = input.readObject() as Date;
                _extern = input.readObject() as Boolean;
                _fullname = input.readObject() as String;
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
                _lastPasswordChange = input.readObject() as Date;
                _locked = input.readObject() as Boolean;
                _password = input.readObject() as String;
                _passwords = input.readObject() as ListCollectionView;
                _preferences = input.readObject() as ListCollectionView;
                _roles = input.readObject() as ListCollectionView;
                _savedPassword = input.readObject() as String;
                _userDetails = input.readObject() as UserDetails;
                _username = input.readObject() as String;
                _version = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
            else {
                _id = function(o:*):Number { return (o is Number ? o as Number : Number.NaN) } (input.readObject());
            }
        }

        override public function writeExternal(output:IDataOutput):void {
            output.writeObject(__initialized);
            output.writeObject(__detachedState);
            if (meta::isInitialized()) {
                super.writeExternal(output);
                output.writeObject(_enabled);
                output.writeObject(_expirationDate);
                output.writeObject(_extern);
                output.writeObject(_fullname);
                output.writeObject(_id);
                output.writeObject(_lastPasswordChange);
                output.writeObject(_locked);
                output.writeObject(_password);
                output.writeObject(_passwords);
                output.writeObject(_preferences);
                output.writeObject(_roles);
                output.writeObject(_savedPassword);
                output.writeObject(_userDetails);
                output.writeObject(_username);
                output.writeObject(_version);
            }
            else {
                output.writeObject(_id);
            }
        }
    }
}